@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "editorutiltest.h"
@@ -46,7 +35,7 @@ void EditorUtilTest::testUpperCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    QTextDocument *document = new QTextDocument(this);
+    auto *document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -76,7 +65,7 @@ void EditorUtilTest::testLowerCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    QTextDocument *document = new QTextDocument(this);
+    auto *document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -106,7 +95,7 @@ void EditorUtilTest::testSentenceCase()
     QFETCH(QString, result);
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
-    QTextDocument *document = new QTextDocument(this);
+    auto *document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
@@ -138,7 +127,7 @@ void EditorUtilTest::testReverseCase()
     QFETCH(int, startcursorposition);
     QFETCH(int, endcursorposition);
 
-    QTextDocument *document = new QTextDocument(this);
+    auto *document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (startcursorposition != -1 && endcursorposition != -1) {
