@@ -1,23 +1,9 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "richtextcomposer.h"
 #include "richtextcomposercontroler.h"
 #include "richtextcomposerimages.h"
 #include "klinkdialog_p.h"
@@ -545,14 +531,6 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::updateLink(con
     }
     cursor.insertText(_linkText, format);
 
-    // Insert a space after the link if at the end of the block so that
-    // typing some text after the link does not carry link formatting
-    if (!linkUrl.isEmpty() && cursor.atBlockEnd()) {
-        cursor.setPosition(cursor.selectionEnd());
-        cursor.setCharFormat(originalFormat);
-        cursor.insertText(QStringLiteral(" "));
-    }
-
     cursor.endEditBlock();
 }
 
